<?php

/**
 * Plugin Name: Dreamfox Media Shipping gateway per Product for Woocommerce
 * Plugin URI: https://www.dreamfoxmedia.com 
 * Version: 2.0.9
 * Author: Dreamfox Media
 * Author URI: https://www.dreamfoxmedia.com 
 * Description: Extend Woocommerce plugin to add shipping methods to a product
 * Requires at least: 5.0
 * Tested up to: 6.1
 * WC requires at least: 5.0.0
 * WC tested up to: 7.0.1
 * @Developer : Marco van Loghum Slaterus ( www.Dreamfoxmedia.com )
 */
/**
 * For multi Network
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( function_exists( 'dfm_sgppfw_fs' ) ) {
    dfm_sgppfw_fs()->set_basename( false, __FILE__ );
} else {
    
    if ( !function_exists( 'dfm_sgppfw_fs' ) ) {
        // Create a helper function for easy SDK access.
        function dfm_sgppfw_fs()
        {
            global  $dfm_sgppfw_fs ;
            
            if ( !isset( $dfm_sgppfw_fs ) ) {
                // Activate multisite network integration.
                if ( !defined( 'WP_FS__PRODUCT_7653_MULTISITE' ) ) {
                    define( 'WP_FS__PRODUCT_7653_MULTISITE', true );
                }
                // Include Freemius SDK.
                require_once dirname( __FILE__ ) . '/freemius/start.php';
                $dfm_sgppfw_fs = fs_dynamic_init( array(
                    'id'             => '7653',
                    'slug'           => 'dfm-shipping-gateway-per-product-for-woocommerce',
                    'premium_slug'   => 'DreamfoxMediaPaymentgatewayperProductforWoocommerce-premium',
                    'type'           => 'plugin',
                    'public_key'     => 'pk_f21a7bb601e07d62b89f55c3a832c',
                    'is_premium'     => false,
                    'premium_suffix' => 'Premium',
                    'has_addons'     => false,
                    'has_paid_plans' => true,
                    'menu'           => array(
                    'slug'    => 'softsdev-product-shippings',
                    'support' => false,
                    'parent'  => array(
                    'slug' => 'woocommerce',
                ),
                ),
                    'is_live'        => true,
                ) );
            }
            
            return $dfm_sgppfw_fs;
        }
        
        // Init Freemius.
        dfm_sgppfw_fs();
        // Signal that SDK was initiated.
        do_action( 'dfm_sgppfw_fs_loaded' );
    }

}

if ( !function_exists( 'is_plugin_active_for_network' ) || !function_exists( 'is_plugin_active' ) ) {
    require_once ABSPATH . '/wp-admin/includes/plugin.php';
}
require_once dirname( __FILE__ ) . '/inc/quick_bulk_edit_patch.php';
/**
 * default variable
 */
define( 'PRODUCT_SHIPPINGS_ITEM_REFERENCE', 'Product Shippings' );
//Rename this constant name so it is specific to your plugin or theme.
/**
 * Check is free plugin is installed then we will deactivate free first
 */
if ( is_plugin_active( 'woocommerce-product-shippings/woocommerce-product-shippings.php' ) ) {
    deactivate_plugins( 'woocommerce-product-shippings/woocommerce-product-shippings.php' );
}
if ( is_plugin_active( 'woocommerce-shipping-gateway-per-product/woocommrece-product-shippings.php' ) ) {
    deactivate_plugins( 'woocommerce-shipping-gateway-per-product/woocommrece-product-shippings.php' );
}
/**
 * Check if WooCommerce is active
 */

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) && !function_exists( 'softsdev_product_shippings_settings' ) || is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) {
    function product_shipping_support_email()
    {
        global  $dreamfox_dd_version ;
        
        if ( isset( $_POST['action'] ) && $_POST['action'] == 'raise_product_shipping_support_email' ) {
            $name = $_POST['name'];
            $email = $_POST['email'];
            $plugin_name = $_POST['plugin_name'];
            $detail_problem = $_POST['detail_problem'];
            $to_email = 'support@dreamfoxmedia.com';
            $sep = "\n\n";
            $subject = 'Support Ticket for the Plugin : Woocommerce Product Shippings premium';
            $message = 'Hi there,' . $sep . 'Here are the details of the support ticket : ' . $sep;
            $message .= ' Name : ' . $name . $sep;
            $message .= ' Email : ' . $email . $sep;
            $message .= ' Plugin name : ' . $plugin_name . $sep;
            $message .= ' Version : ' . $dreamfox_dd_version . $sep;
            $message .= ' Details of Problem : ' . $sep . $detail_problem . $sep;
            $message .= ' Thanks,' . $sep;
            $message .= 'Admin';
            wp_mail(
                $to_email,
                $subject,
                $message,
                array( 'From: ' . $name . ' <' . $email . '>' )
            );
            softsdev_notice( 'Support email has been sent successfully', 'updated' );
            reset( $_POST );
        }
    
    }
    
    add_action( 'init', 'product_shipping_support_email' );
    // display default admin notice
    function product_shipping_ignore_notice()
    {
        if ( isset( $_GET['product-shipping-ignore-notice'] ) ) {
            update_option( 'product_shipping_alert', 1 );
        }
    }
    
    add_action( 'admin_init', 'product_shipping_ignore_notice' );
    // Submenu on woocommerce section
    /* ----------------------------------------------------- */
    /**
     * Type: updated,error,update-nag
     */
    if ( !function_exists( 'softsdev_notice' ) ) {
        function softsdev_notice( $message, $type )
        {
            $html = <<<EOD
<div class="{$type} notice">
<p>{$message}</p>
</div>
EOD;
            echo  $html ;
        }
    
    }
    /**
     * 
     * @param string $text
     * @return string
     */
    function softsdev_product_shippings_footer_text( $text )
    {
        if ( isset( $_GET['page'] ) && strpos( plugin_basename( wp_unslash( $_GET['page'] ) ), 'softsdev-product-shippings' ) === 0 ) {
            $text = '<a href="https://www.dreamfoxmedia.com" target="_blank">www.dreamfoxmedia.com</a>';
        }
        return $text;
    }
    
    /**
     * 
     * @param string $text
     * @return string
     */
    function softsdev_product_shippings_update_footer( $text )
    {
        if ( isset( $_GET['page'] ) && strpos( plugin_basename( wp_unslash( $_GET['page'] ) ), 'softsdev-product-shippings' ) === 0 ) {
            $text = 'Version 1.4.1';
        }
        return $text;
    }
    
    add_action( 'add_meta_boxes', 'wps_ship_meta_box_add', 50 );
    function wps_ship_meta_box_add()
    {
        add_meta_box(
            'shippings',
            'shippings',
            'wps_shipping_form',
            'product',
            'side',
            'core'
        );
    }
    
    if ( !function_exists( 'wps_shipping_get_shippings_meta' ) ) {
        function wps_shipping_get_shippings_meta( $product_id )
        {
            $shippings = get_post_meta( $product_id, 'shippings', true );
            if ( !is_array( $shippings ) ) {
                $shippings = [];
            }
            return $shippings;
        }
    
    }
    /**
     * 
     * @global type $post
     * @global type $woocommerce
     */
    function wps_shipping_form()
    {
        global  $post, $woocommerce ;
        $productIds = get_option( 'woocommerce_product_apply_ship', array() );
        $postshippings = wps_shipping_get_shippings_meta( $post->ID );
        
        if ( is_array( $productIds ) ) {
            foreach ( $productIds as $key => $product ) {
                $shippings = wps_shipping_get_shippings_meta( $product );
                if ( !get_post( $product ) || $shippings && !count( $shippings ) ) {
                    unset( $productIds[$key] );
                }
            }
            $shippings = apply_filters( 'softsdev_shipping_method', $shippings );
        }
        
        update_option( 'woocommerce_product_apply_ship', $productIds );
        $shipping_methods = $woocommerce->shipping->load_shipping_methods();
        if ( $shipping_methods ) {
            foreach ( $shipping_methods as $key => $method ) {
                if ( apply_filters( 'softsdev_show_disabled_shippings', false ) || $method->enabled == 'yes' ) {
                    $shippings[$key] = $method;
                }
            }
        }
        foreach ( $shippings as $ship ) {
            
            if ( $ship->enabled === 'yes' ) {
                $checked = '';
                if ( is_array( $postshippings ) && in_array( $ship->id, $postshippings ) ) {
                    $checked = ' checked="checked" ';
                }
                ?>
                <input type="checkbox" <?php 
                echo  $checked ;
                ?> value="<?php 
                echo  $ship->id ;
                ?>" name="ship[]" id="ship_<?php 
                echo  $ship->id ;
                ?>" />
                <label for="ship_<?php 
                echo  $ship->id ;
                ?>"><?php 
                echo  $ship->method_title ;
                ?></label>
                <br />
        <?php 
            }
        
        }
    }
    
    add_action(
        'save_post',
        'wps_ship_meta_box_save',
        10,
        2
    );
    /**
     * 
     * @param type $post_id
     * @param type $post
     * @return type
     */
    function wps_ship_meta_box_save( $post_id, $post )
    {
        // Restrict to save for autosave
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE || isset( $_REQUEST['action'] ) && sanitize_title( $_REQUEST['action'] ) != 'editpost' ) {
            return $post_id;
        }
        // Restrict to save for revisions
        if ( isset( $post->post_type ) && $post->post_type == 'revision' ) {
            return $post_id;
        }
        delete_post_meta( $post_id, 'shippings' );
        
        if ( get_post_type() === 'product' && isset( $_POST['ship'] ) ) {
            $productIds = get_option( 'woocommerce_product_apply_ship' );
            
            if ( is_array( $productIds ) && !in_array( $post_id, $productIds ) ) {
                $productIds[] = $post_id;
                update_option( 'woocommerce_product_apply_ship', $productIds );
            }
            
            //delete_post_meta($post_id, 'shippings');
            $shippings = array();
            $post_ships = array_filter( array_map( 'sanitize_title', $_POST['ship'] ) );
            if ( $post_ships ) {
                foreach ( $post_ships as $ship ) {
                    $shippings[] = $ship;
                }
            }
            
            if ( count( $shippings ) ) {
                update_post_meta( $post_id, 'shippings', $shippings );
            } else {
                delete_post_meta( $post_id, 'shippings' );
            }
        
        }
    
    }
    
    /**
     * 
     * @global type $woocommerce
     * @param type $available_methods
     * @return type
     */
    /**
     * 
     * @global type $woocommerce
     * @param type $available_methods
     * @return type
     */
    function wps_shipping_method_disable_country( $packages )
    {
        foreach ( $packages as &$package ) {
            $items = $package['contents'];
            $itemsShips = '';
            $ships = array();
            if ( is_array( $items ) ) {
                foreach ( $items as $item ) {
                    $itemsShips = get_post_meta( $item['product_id'], 'shippings', true );
                    
                    if ( is_string( $itemsShips ) ) {
                        $ships[] = $itemsShips;
                    } else {
                        $ships = array_merge( $ships, $itemsShips );
                    }
                
                }
            }
            
            if ( count( $ships ) > 0 ) {
                $available_methods =& $package['rates'];
                $method_ids = [];
                foreach ( $available_methods as $shipping_method ) {
                    $method_ids[] = $shipping_method->method_id;
                }
                $filtered_ship = array_intersect( $ships, $method_ids );
                
                if ( count( $filtered_ship ) > 0 ) {
                    foreach ( $available_methods as $key => $shipping ) {
                        if ( !in_array( $shipping->method_id, $filtered_ship ) ) {
                            unset( $available_methods[$key] );
                        }
                    }
                } elseif ( count( $available_methods ) > 0 ) {
                    #if common ship not found
                    /**
                     * logic for default ship
                     * min max
                     */
                    $cost_rate = array();
                    foreach ( $available_methods as $key => $shipping ) {
                        $cost_rate[$key] = $shipping->cost;
                    }
                    $softsdev_wps_plugin_settings = get_option( 'sdwps_plugin_settings', array(
                        'default_option_mp' => 'expensive',
                    ) );
                    switch ( $softsdev_wps_plugin_settings['default_option_mp'] ) {
                        case 'expensive':
                            $aplicable_shipping = array_keys( $cost_rate, max( $cost_rate ) );
                            break;
                        case 'cheapest':
                            $aplicable_shipping = array_keys( $cost_rate, min( $cost_rate ) );
                            break;
                        default:
                            $aplicable_shipping = array();
                            break;
                    }
                    /**
                     * remove non aplicable shipping
                     */
                    foreach ( $available_methods as $_key => $_shipping ) {
                        if ( !in_array( $_key, $aplicable_shipping ) ) {
                            unset( $available_methods[$_key] );
                        }
                    }
                }
            
            }
        
        }
        return $packages;
    }
    
    // update new filter as depricated woocommerce_available_shipping_methods
    add_filter( 'woocommerce_shipping_packages', 'wps_shipping_method_disable_country', 99 );
    add_filter( 'softsdev_show_disabled_shippings', function () {
        return true;
    } );
    /**
     * 
     */
    function update_user_database()
    {
        $is_shipping_updated = get_option( 'is_shipping_updated' );
        
        if ( !$is_shipping_updated ) {
            $args = array(
                'posts_per_page' => -1,
                'post_type'      => 'product',
                'fields'         => 'ids',
            );
            $products = get_posts( $args );
            foreach ( $products as $pro_id ) {
                $itemsShips = wps_shipping_get_shippings_meta( $pro_id );
                if ( empty($itemsShips) ) {
                    delete_post_meta( $pro_id, 'shippings' );
                }
            }
            update_option( 'is_shipping_updated', true );
        }
    
    }
    
    add_action( 'wp_head', 'update_user_database' );
    add_action( 'admin_menu', 'softsdev_product_shippings_submenu_page' );
    function softsdev_product_shippings_submenu_page()
    {
        add_submenu_page(
            'woocommerce',
            __( 'Product Shippings', 'softsdev' ),
            __( 'Product Shippings', 'softsdev' ),
            'manage_options',
            'softsdev-product-shippings',
            'softsdev_product_shippings_settings'
        );
    }
    
    function softsdev_product_shippings_enqueue()
    {
        wp_enqueue_style( 'softsdev_product_shippings_enqueue', plugin_dir_url( __FILE__ ) . '/css/style.css' );
    }
    
    add_action( 'admin_enqueue_scripts', 'softsdev_product_shippings_enqueue' );
    function softsdev_product_shippings_settings()
    {
        wp_register_script( 'dd_horztab_script', plugins_url( '/js/dd_horizontal_tabs.js', __FILE__ ) );
        wp_enqueue_script( 'dd_horztab_script' );
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings', 'softsdev' ) . '</h2></div>' ;
        ?>
        <div class="left-dd-paid ">
            <div class="left_box_container">
                <ul class="horz_tabs">
                    <li <?php 
        if ( !isset( $_GET['tab'] ) ) {
            ?> class="active" <?php 
        }
        ?> id="information">
                        <a href="javascript:;">Information</a>
                    </li>
                    <li id="settings" <?php 
        if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'settings' ) {
            ?>class="active" <?php 
        }
        ?>>
                        <a href="javascript:;">Settings</a>
                    </li>
                    <li id="newsletter" <?php 
        if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'newsletter' ) {
            ?>class="active" <?php 
        }
        ?>>
                        <a href="javascript:;">Newsletter</a>
                    </li>
                    <li id="faq">
                        <a href="javascript:;">FAQ</a>
                    </li>
                    <li id="support" <?php 
        if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'support' ) {
            ?>class="active" <?php 
        }
        ?>>
                        <a href="javascript:;">Support</a>
                    </li>
                    <li id="dfmplugins">
                        <a href="javascript:;">DFM Plugins</a>
                    </li>
                </ul>
            </div>
        </div>
        <div class="right-dd-paid ">
            <div id="tab_information" class="postbox <?php 
        if ( !isset( $_GET['tab'] ) ) {
            ?>active<?php 
        }
        ?>" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - Information', 'softsdev' ) . '</h2></div>' ;
        ?>
                <p>This plugin for woocommerce lets you select the available shipping gateways for each individual product.
                    You can select for eacht individual product the shipping gateway that will be used by checkout.
                    If no selection is made, then the default shipping gateways are displayed.
                    If you for example only select local delivery then only local delivery will available for that product by checking out.</p>
                <p>This plugin allows you to improve your customer service by giving the best shipping service for your customers.</p>
			<img src="<?php 
        echo  plugins_url( 'img/attention.png', __FILE__ ) ;
        ?>"><br>
			IMPORTANT: We are using a new license system. If you have trouble with your license then see this link:<br>
			<a href="https://support.dreamfoxmedia.com/en/article/transferring-our-licenses-from-our-own-system-to-freemius-1skikqp/" target="_blank">Click here to see the complete article</a>
			
            </div>

            <div id="tab_settings" class="postbox <?php 
        if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'settings' ) {
            ?>active<?php 
        }
        ?>" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - Settings', 'softsdev' ) . '</h2></div>' ;
        ?>
                <div id="freeversion">
                	<div id="woo_sdwps">
                        <div>
                            <h3 class="hndle"><?php 
        echo  __( 'Multiple products in cart with different shipping gateway', 'softsdev' ) ;
        ?></h3>
                            <select id="sdwps_default_payment" name="sdwps_setting[default_option_mp]" disabled="disabled">
                                <option value="none" <?php 
        selected( $default_option_mp, 'none' );
        ?>>Do not show shipping gateway</option>
                                <option value="cheapest" <?php 
        selected( $default_option_mp, 'cheapest' );
        ?>>Choose the cheapest gateway</option>
                                <option value="expensive" <?php 
        selected( $default_option_mp, 'expensive' );
        ?>>Choose the expensive gateway</option>
                            </select>
                            <br />
                            <br />
                            <small><?php 
        echo  __( 'In case of multiple products from diffrent shipping', 'softsdev' ) ;
        ?></small>
                        </div>
                        <br />
                        <input class="button-large button-primary" type="submit" value="Save changes" disabled="disabled" />

                        <div style="color: red;margin-top: 30px;">This is a Premium feature.</div>
                    </div>
                </div>

                <?php 
        ?>
            </div>
            <div id="tab_newsletter" class="postbox" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - Newsletter', 'softsdev' ) . '</h2></div>' ;
        ?>
                <!-- Begin SendInBlue Form -->
				<iframe width="540" height="505" src="https://322fdba5.sibforms.com/serve/MUIEAFes3bCeqXwMM73xl9lmUpZWzxWQzKtb6q7UAmyNuOkeNZXOSXgXqzs-pZVxVfFj-u6BapzchhtobGU0BRe75Z4OdQAha2ig6ontnxzfNd4sewU5EZZFzBwDgYeAMLvQhCbACfNIkkX7h7VvnPlE2i8KmM0b_XAO6JL01j9SBk1ft5Qn7vyVVzjMvMJG135pRnZ0URuEd_pY" frameborder="0" scrolling="auto" allowfullscreen style="display: block;margin-left: auto;margin-right: auto;max-width: 100%;"></iframe>
				<!--  END -->
            </div>
            <div id="tab_faq" class="postbox" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - FAQ', 'softsdev' ) . '</h2></div>' ;
        ?>
                <div>
                <!-- Begin freshdeskForm -->
				If you want to read the FAQ about this plugin then click on below link. We will take you right there in a breeze.<br>You can also click on the help button in the bottom right corner to see the most ask questions.
				<script>
	window.fwSettings={
	'widget_id':72000002383
	};
	!function(){if("function"!=typeof window.FreshworksWidget){var n=function(){n.q.push(arguments)};n.q=[],window.FreshworksWidget=n}}() 
</script>
<script type='text/javascript' src='https://widget.freshworks.com/widgets/72000002383.js' async defer></script>
				<a href="https://support.dreamfoxmedia.com/support/solutions/72000275599/" target="_blank">Click here to see the Shipping Plugin FAQ</a>
                <!--  END - We recommend to place the above code in head tag of your website html -->
                 </div>
            </div>
            <div id="tab_support" class="postbox <?php 
        if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'support' ) {
            ?>active<?php 
        }
        ?>" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - Support Form', 'softsdev' ) . '</h2></div>' ;
        $user = wp_get_current_user();
        $plugin_data = get_plugin_data( __FILE__ );
        ?>
                <div class="supportform" style="display:block; background-color:#FFF; margin:20px; padding:10px;">
                    <form action="admin.php?page=softsdev-product-shippings&tab=support" id="support_form" method="post" class="mymail-form-2 mymail-form mymail-form-submit extern">
                        <table width="100%" class="form-table">
                            <tr>
                                <th>
                                    <label><?php 
        echo  __( 'Name', 'dreamfox_dd' ) ;
        ?></label>
                                    <img width="16" height="16" src="<?php 
        echo  plugins_url( 'img/help.png', __FILE__ ) ;
        ?>" class="help_tip" title="<?php 
        echo  __( 'Name', 'dreamfox_dd' ) ;
        ?>">
                                </th>
                                <td>
                                    <input id="name" name="name" type="textbox" size="30" value="<?php 
        echo  $user->data->user_nicename ;
        ?>" />
                                </td>
                            </tr>
                            <tr>
                                <th>
                                    <label><?php 
        echo  __( 'Email', 'dreamfox_dd' ) ;
        ?></label>
                                    <img width="16" height="16" src="<?php 
        echo  plugins_url( 'img/help.png', __FILE__ ) ;
        ?>" class="help_tip" title="<?php 
        echo  __( 'Email', 'dreamfox_dd' ) ;
        ?>">
                                </th>
                                <td>
                                    <input id="email" name="email" type="textbox" size="30" value="<?php 
        echo  $user->data->user_email ;
        ?>" />
                                </td>
                            </tr>
                            <tr>
                                <th>
                                    <label><?php 
        echo  __( 'Plugin Name', 'dreamfox_dd' ) ;
        ?></label>
                                    <img width="16" height="16" src="<?php 
        echo  plugins_url( 'img/help.png', __FILE__ ) ;
        ?>" class="help_tip" title="<?php 
        echo  __( 'Plugin Name', 'dreamfox_dd' ) ;
        ?>">
                                </th>
                                <td>
                                    <input readonly id="plugin_name" name="plugin_name" type="textbox" size="60" value="Woocommerce Product Shippings Full" />
                                </td>
                            </tr>
                            <tr>
                                <th>
                                    <label><?php 
        echo  __( 'Version Number', 'dreamfox_dd' ) ;
        ?></label>
                                    <img width="16" height="16" src="<?php 
        echo  plugins_url( 'img/help.png', __FILE__ ) ;
        ?>" class="help_tip" title="<?php 
        echo  __( 'Plugin Name', 'dreamfox_dd' ) ;
        ?>">
                                </th>
                                <td>
                                    <input readonly id="version_number" name="version_number" type="textbox" size="30" value="<?php 
        echo  $plugin_data['Version'] ;
        ?>
" />
                                </td>
                            </tr>
                            <tr>
                                <th>
                                    <label><?php 
        echo  __( 'Details of Problem', 'dreamfox_dd' ) ;
        ?></label>
                                    <img width="16" height="16" src="<?php 
        echo  plugins_url( 'img/help.png', __FILE__ ) ;
        ?>" class="help_tip" title="<?php 
        echo  __( 'Details of Problem', 'dreamfox_dd' ) ;
        ?>">
                                </th>
                                <td>
                                    <textarea name="detail_problem" id="detail_problem" style="width:300px;height:300px"></textarea>
                                    <input type="hidden" name="action" value="raise_product_shipping_support_email" />
                                </td>
                            </tr>
                            <tr>
                                <th>&nbsp;</th>
                                <td align="left">
                                    <button onclick="support_form();" type="button" class="button-large button-primary">Submit Support Ticket</button>
                                </td>
                            </tr>
                        </table>
                    </form>
                </div>
            </div>
            <div id="tab_dfmplugins" class="postbox" style="padding: 10px; margin: 10px 0px;">
                <?php 
        add_filter( 'admin_footer_text', 'softsdev_product_shippings_footer_text' );
        add_filter( 'update_footer', 'softsdev_product_shippings_update_footer' );
        echo  '<div class="wrap wrap-mc-paid"><div id="icon-tools" class="icon32"></div>' ;
        echo  '<h2 class="title">' . __( 'Woocommerce Product Shippings - Dreamfox Media Plugins', 'softsdev' ) . '</h2></div>' ;
        ?>
                <?php 
        $url = 'https://raw.githubusercontent.com/dreamfoxmedia/dreamfoxmedia/gh-pages/plugins/dfmplugins.json';
        $response = wp_remote_get( $url, array() );
        $response_code = wp_remote_retrieve_response_code( $response );
        $response_body = wp_remote_retrieve_body( $response );
        
        if ( $response_code != 200 || is_wp_error( $response ) ) {
            echo  '<div class="error below-h2"><p>There was an error retrieving the list from the server.</p></div>' ;
            switch ( $response_code ) {
                case '403':
                    echo  '<div class="error below-h2"><p>Seems your host is blocking <strong>' . dirname( $url ) . '</strong>. Please request to white list this domain </p></div>' ;
                    break;
            }
            wp_die();
        }
        
        $addons = json_decode( $response_body );
        // set_transient( 'mymail_addons', $addons, 3600 );
        $plugin_http_path = plugins_url();
        ?>
                <div class="wrap">
                    <h3>Here you see our great Free and Premium Plugins of Dreamfox Media</h3>
                    <link href="<?php 
        echo  $plugin_http_path ;
        ?>/woocommerce-delivery-date-premium/css/addons-style.min.css?ver=2.1.23" rel="stylesheet" type="text/css">
                    <ul class="addons-wrap">
                        <?php 
        foreach ( $addons as $addon ) {
            if ( !empty($addon->hidden) ) {
                continue;
            }
            $addon->link = ( isset( $addon->link ) ? add_query_arg( array(
                'utm_source'   => 'Dreamfox Media Plugin Page',
                'utm_medium'   => 'link',
                'utm_campaign' => 'Dreamfox Plugins Add Ons',
            ), $addon->link ) : '' );
            ?>
                            <li class="mymail-addon <?php 
            if ( !empty($addon->is_free) ) {
                echo  ' is-free' ;
            }
            if ( !empty($addon->is_feature) ) {
                echo  ' is-feature' ;
            }
            
            if ( isset( $addon->image ) ) {
                $image = str_replace( 'http//', '//', $addon->image );
            } elseif ( isset( $addon->image_ ) ) {
                $image = str_replace( 'http//', '//', $addon->image_ );
            }
            
            ?>">
                                <div class="bgimage" style="min-height: 500px; background-repeat: no-repeat; background-image:url(<?php 
            echo  $image ;
            ?>)">
                                    <?php 
            
            if ( isset( $addon->wpslug ) ) {
                ?>
                                        <a href="plugin-install.php?tab=plugin-information&plugin=<?php 
                echo  dirname( $addon->wpslug ) ;
                ?>&from=import&TB_iframe=true&width=745&height=745" class="thickbox">&nbsp;</a>
                                    <?php 
            } else {
                ?>
                                        <a href="<?php 
                echo  $addon->link ;
                ?>">&nbsp;</a>
                                    <?php 
            }
            
            ?>
                                </div>
                                <h4><?php 
            echo  $addon->name ;
            ?></h4>
                                <p class="author">by
                                    <?php 
            
            if ( $addon->author_url ) {
                echo  '<a href="' . $addon->author_url . '">' . $addon->author . '</a>' ;
            } else {
                echo  $addon->author ;
            }
            
            ?>
                                </p>
                                <p class="description"><?php 
            echo  $addon->description ;
            ?></p>
                                <div class="action-links">
                                    <?php 
            
            if ( !empty($addon->wpslug) ) {
                ?>
                                        <?php 
                
                if ( is_dir( dirname( WP_PLUGIN_DIR . '/' . $addon->wpslug ) ) ) {
                    ?>
                                            <?php 
                    
                    if ( is_plugin_active( $addon->wpslug ) ) {
                        ?>
                                                <a class="button" href="<?php 
                        echo  wp_nonce_url( 'plugins.php?action=deactivate&amp;plugin=' . $addon->wpslug, 'deactivate-plugin_' . $addon->wpslug ) ;
                        ?>"><?php 
                        _e( 'Deactivate', 'mymail' );
                        ?></a>
                                            <?php 
                    } elseif ( is_plugin_inactive( $addon->wpslug ) ) {
                        ?>
                                                <a class="button" href="<?php 
                        echo  wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $addon->wpslug, 'activate-plugin_' . $addon->wpslug ) ;
                        ?>"><?php 
                        _e( 'Activate', 'mymail' );
                        ?></a>
                                            <?php 
                    }
                    
                    ?>
                                        <?php 
                } else {
                    ?>
                                            <?php 
                    
                    if ( current_user_can( 'install_plugins' ) || current_user_can( 'update_plugins' ) ) {
                        ?>
                                                <a class="button button-primary" href="<?php 
                        echo  wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . dirname( $addon->wpslug ) . '&mymail-addon' ), 'install-plugin_' . dirname( $addon->wpslug ) ) ;
                        ?>"><?php 
                        _e( 'Install', 'mymail' );
                        ?></a>
                                            <?php 
                    }
                    
                    ?>
                                        <?php 
                }
                
                ?>
                                    <?php 
            } else {
                ?>
                                        <a class="button button-primary" href="<?php 
                echo  $addon->link ;
                ?>"><?php 
                _e( 'Purchase', 'mymail' );
                ?></a>
                                    <?php 
            }
            
            ?>
                                </div>
                            </li>
                        <?php 
        }
        ?>
                    </ul>
                </div>
            </div>
    <?php 
    }

}
